@@ -10,9 +10,10 @@ from typing import Any
 from . import converters
 from sqlconstructor.utils.classes.string_convertible import StringConvertible
 from sqlconstructor.utils.classes.container_convertible import ContainerConvertible
+from sqlconstructor.utils.classes.json_convertion_requier import JsonConvertionRequier
 
 
-class SqlVal(StringConvertible, ContainerConvertible):
+class SqlVal(StringConvertible, JsonConvertionRequier, ContainerConvertible):
     """
     SqlVal class is invented for better experience to convert any value to sql string.
     """
@@ -20,7 +21,10 @@ class SqlVal(StringConvertible, ContainerConvertible):
         self,
         statement: Any,
     ):
-        self.converted = converters.convert_any_to_sql(statement)
+        self.statement = statement
 
     def __str__(self) -> str:
-        return self.converted
+        return converters.convert_any_to_sql(self.statement)
+
+    def __as_json__(self) -> str:
+        return converters.convert_any_to_sql(self.statement, is_json_context=True)
