@@ -7,7 +7,7 @@ from sqlconstructor.constants import AND_MODE
 def test_and_two_filters():
     first_filter = SqlFilter(a=1)
     second_filter = SqlFilter(b=2)
-    assert (first_filter & second_filter) == '\n'.join(
+    assert str(first_filter & second_filter) == '\n'.join(
         (
             'a=1',
             AND_MODE,
@@ -20,7 +20,7 @@ def test_and_three_filters():
     first_filter = SqlFilter(a=1)
     second_filter = SqlFilter(b=2)
     third_filter = SqlFilter(c=3)
-    assert (first_filter & second_filter & third_filter) == '\n'.join(
+    assert str(first_filter & second_filter & third_filter) == '\n'.join(
         (
             'a=1',
             AND_MODE,
